<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.qml" line="44"/>
        <source>cuteTube-QML - 0.5.1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="56"/>
        <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AccountDetailsDialog</name>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="10"/>
        <location filename="../AccountDetailsDialog.qml" line="26"/>
        <source>New Account</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="15"/>
        <source>Edit Account</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="46"/>
        <source>Database error. Unable to save account</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="82"/>
        <source>Username</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="107"/>
        <source>Password</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="132"/>
        <source>Default?</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AccountsDialog</name>
    <message>
        <location filename="../AccountsDialog.qml" line="79"/>
        <source>YouTube Accounts</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AddCommentDialog</name>
    <message>
        <location filename="../AddCommentDialog.qml" line="6"/>
        <source>Add Comment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="15"/>
        <source>Share Via </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="60"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="87"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="124"/>
        <source>Message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddToPlaylistDialog</name>
    <message>
        <location filename="../AddToPlaylistDialog.qml" line="31"/>
        <source>Add To Playlist</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ArchiveListView</name>
    <message>
        <location filename="../ArchiveListView.qml" line="72"/>
        <source>Multi-select</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="74"/>
        <source>Delete from archive</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="74"/>
        <source>Delete from device</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>BusyDialog</name>
    <message>
        <location filename="../BusyDialog.qml" line="50"/>
        <source>Loading...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ChangeUserDialog</name>
    <message>
        <location filename="../ChangeUserDialog.qml" line="50"/>
        <source>Change Current User</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>CommentsDelegate</name>
    <message>
        <location filename="../CommentsDelegate.qml" line="20"/>
        <location filename="../CommentsDelegate.qml" line="22"/>
        <source>By </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../CommentsDelegate.qml" line="21"/>
        <location filename="../CommentsDelegate.qml" line="23"/>
        <source> on </source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ConfirmExitDialog</name>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="47"/>
        <source>Hold it!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="58"/>
        <source>cuteTube is currently downloading. Do you really want to exit?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="71"/>
        <source>Yes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="81"/>
        <source>No</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <location filename="../../../controller.cpp" line="123"/>
        <source>Video deleted from device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="126"/>
        <source>Unable to delete video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="130"/>
        <source>Video not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="185"/>
        <source>Copied to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadListDelegate</name>
    <message>
        <location filename="../DownloadListDelegate.qml" line="49"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../DownloadListDelegate.qml" line="49"/>
        <source>Queued</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../DownloadListDelegate.qml" line="49"/>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../DownloadListDelegate.qml" line="66"/>
        <source>Downloading</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <location filename="../../../downloadmanager.cpp" line="37"/>
        <location filename="../../../downloadmanager.cpp" line="66"/>
        <location filename="../../../downloadmanager.cpp" line="159"/>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../downloadmanager.cpp" line="121"/>
        <source>Downloading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../downloadmanager.cpp" line="156"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileChooserDialog</name>
    <message>
        <location filename="../FileChooserDialog.qml" line="29"/>
        <source>Choose Video File</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <location filename="../HomeView.qml" line="102"/>
        <source>Settings</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="102"/>
        <source>Accounts</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="102"/>
        <source>About</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="154"/>
        <source>My Channel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="178"/>
        <source>Most Recent</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="202"/>
        <source>Most Viewed</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="226"/>
        <source>Archive</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MenuBar</name>
    <message>
        <location filename="../MenuBar.qml" line="24"/>
        <source>Menu</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MenuBar.qml" line="45"/>
        <source>Back</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MenuBar.qml" line="57"/>
        <source>Exit</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MyAccountView</name>
    <message>
        <location filename="../MyAccountView.qml" line="75"/>
        <source>Upload video</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="115"/>
        <source>My Uploads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="121"/>
        <source>Uploads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="139"/>
        <source>My Favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="145"/>
        <source>Favourites</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="169"/>
        <source>Playlists</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="193"/>
        <source>Subscriptions</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="208"/>
        <source>Signed in as:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>NewPlaylistDialog</name>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="34"/>
        <source>New Playlist</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="46"/>
        <source>Title</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="71"/>
        <source>Description (optional)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="95"/>
        <source>Private?</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>NoAccountDialog</name>
    <message>
        <location filename="../NoAccountDialog.qml" line="60"/>
        <source>Hi there!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="71"/>
        <source>My name&apos;s Cutey. My buddy Clippy tells me it&apos;s the first time you&apos;ve used cuteTube. Would you like to add a YouTube account?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="84"/>
        <source>Yes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="98"/>
        <source>Go Away</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>NotificationArea</name>
    <message>
        <location filename="../NotificationArea.qml" line="50"/>
        <source>No active downloads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NotificationArea.qml" line="145"/>
        <source>Downloads</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>OAuthDialog</name>
    <message>
        <location filename="../OAuthDialog.qml" line="8"/>
        <source>Authorisation For </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="27"/>
        <source>Error obtaining facebook authorisation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="117"/>
        <source>Enter pin code</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaylistDelegate</name>
    <message>
        <location filename="../PlaylistDelegate.qml" line="31"/>
        <source> videos</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PlaylistVideosView</name>
    <message>
        <location filename="../PlaylistVideosView.qml" line="60"/>
        <source>Multi-select</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="62"/>
        <source>Download video</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="62"/>
        <source>Download audio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="63"/>
        <source>Add to favourites</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="63"/>
        <source>Add to playlist</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="63"/>
        <source>Copy to clipboard</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="117"/>
        <source>No videos found</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PlaylistsView</name>
    <message>
        <location filename="../PlaylistsView.qml" line="61"/>
        <source>New playlist created</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../PlaylistsView.qml" line="109"/>
        <source>New playlist</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../PlaylistsView.qml" line="137"/>
        <source>No playlists found</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.qml" line="116"/>
        <location filename="../SearchBar.qml" line="126"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="117"/>
        <location filename="../SearchBar.qml" line="119"/>
        <source>Relevance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="120"/>
        <location filename="../SearchBar.qml" line="122"/>
        <source>Rating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="123"/>
        <source>Views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="176"/>
        <source>Order by:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../SettingsDialog.qml" line="125"/>
        <source>Your saved searches have been cleared</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="128"/>
        <source>Database error. Unable to clear searches</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="177"/>
        <source>Settings</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="211"/>
        <source>Playback quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="219"/>
        <source>Download quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="227"/>
        <source>Start downloads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="235"/>
        <source>Download location</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="243"/>
        <source>Screen orientation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="251"/>
        <source>Media player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="116"/>
        <location filename="../SettingsDialog.qml" line="268"/>
        <location filename="../SettingsDialog.qml" line="422"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="95"/>
        <location filename="../SettingsDialog.qml" line="294"/>
        <source>Playback Quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="98"/>
        <location filename="../SettingsDialog.qml" line="312"/>
        <source>Download Quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="101"/>
        <location filename="../SettingsDialog.qml" line="330"/>
        <source>Start Downloads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="107"/>
        <location filename="../SettingsDialog.qml" line="368"/>
        <source>Screen Orientation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="20"/>
        <location filename="../SettingsDialog.qml" line="110"/>
        <location filename="../SettingsDialog.qml" line="386"/>
        <source>Media Player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="16"/>
        <location filename="../SettingsDialog.qml" line="17"/>
        <source>Mobile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="16"/>
        <location filename="../SettingsDialog.qml" line="17"/>
        <source>High Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="18"/>
        <location filename="../SettingsDialog.qml" line="36"/>
        <location filename="../SettingsDialog.qml" line="62"/>
        <source>Automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="18"/>
        <location filename="../SettingsDialog.qml" line="39"/>
        <source>Manually</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="19"/>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="19"/>
        <source>Landscape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="19"/>
        <source>Portrait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="21"/>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="21"/>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="22"/>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="22"/>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="35"/>
        <location filename="../SettingsDialog.qml" line="63"/>
        <source>Queued</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="66"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="69"/>
        <source>Your settings have been saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="74"/>
        <location filename="../SettingsDialog.qml" line="104"/>
        <source>Download Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="76"/>
        <source>Download Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="113"/>
        <location filename="../SettingsDialog.qml" line="259"/>
        <location filename="../SettingsDialog.qml" line="404"/>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="436"/>
        <source>Clear saved searches</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Sharing</name>
    <message>
        <location filename="../../../sharing.cpp" line="78"/>
        <source>Error - Server repsonse is: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SubscriptionsView</name>
    <message>
        <location filename="../SubscriptionsView.qml" line="48"/>
        <source>You have unsubscribed to &apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="107"/>
        <location filename="../SubscriptionsView.qml" line="122"/>
        <source>Latest Subscription Videos</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="135"/>
        <source>No subscriptions found</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../UploadDialog.qml" line="8"/>
        <source>Cars &amp; Vehicles</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="8"/>
        <source>Comedy</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="9"/>
        <source>Education</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="9"/>
        <location filename="../UploadDialog.qml" line="19"/>
        <source>Entertainment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="10"/>
        <source>Film and Animation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="10"/>
        <source>Gaming</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="11"/>
        <source>Howto &amp; Style</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="11"/>
        <source>Music</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="11"/>
        <source>News &amp; Politics</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="12"/>
        <source>Non-profits &amp; Activism</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="12"/>
        <source>People &amp; Blogs</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="13"/>
        <source>Pets &amp; Animals</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="13"/>
        <source>Science &amp; Technology</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="14"/>
        <source>Sport</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="14"/>
        <source>Travel &amp; Events</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="35"/>
        <location filename="../UploadDialog.qml" line="251"/>
        <source>Category</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="114"/>
        <source>Upload Video</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="138"/>
        <source>File</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="147"/>
        <location filename="../UploadDialog.qml" line="259"/>
        <source>None chosen</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="163"/>
        <source>Title</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="188"/>
        <source>Description (optional)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="212"/>
        <source>Tags (seperated by commas)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="237"/>
        <source>Private?</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UploadProgressDialog</name>
    <message>
        <location filename="../UploadProgressDialog.qml" line="6"/>
        <source>Starting upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="30"/>
        <source>Upload Progress</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="42"/>
        <source>Filename</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="57"/>
        <source>Title</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Abort</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Close</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <location filename="../UploadProgressDialog.qml" line="97"/>
        <location filename="../UploadProgressDialog.qml" line="115"/>
        <source>Upload is in progress</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserInfoDialog</name>
    <message>
        <location filename="../UserInfoDialog.qml" line="120"/>
        <source>Subscribers</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="134"/>
        <source>Videos</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UserVideosView</name>
    <message>
        <location filename="../UserVideosView.qml" line="84"/>
        <source>You have subscribed to &apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="88"/>
        <source>You have unsubscribed to &apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="110"/>
        <source>Multi-select</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="112"/>
        <source>Download video</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="112"/>
        <source>Download audio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="113"/>
        <source>Add to favourites</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="113"/>
        <source>Add to playlist</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="113"/>
        <source>Copy to clipboard</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="166"/>
        <source>No videos found</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="218"/>
        <source>Subscribers</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="232"/>
        <source>Videos</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="255"/>
        <source>Unsubscribe</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="255"/>
        <source>Subscribe</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>VideoInfoView</name>
    <message>
        <location filename="../VideoInfoView.qml" line="16"/>
        <source>No description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="71"/>
        <source>Your comment has been added</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="74"/>
        <source>Your rating has been added</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="81"/>
        <source>Video shared on facebook</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="103"/>
        <source>Add to favourites</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="103"/>
        <source>Add to playlist</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="103"/>
        <source>Copy to clipboard</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="104"/>
        <source>Share via facebook</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="123"/>
        <location filename="../VideoInfoView.qml" line="131"/>
        <location filename="../VideoInfoView.qml" line="470"/>
        <location filename="../VideoInfoView.qml" line="494"/>
        <location filename="../VideoInfoView.qml" line="599"/>
        <source>You are not signed in to a YouTube account</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="271"/>
        <source>Info</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="310"/>
        <source>Comments</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="349"/>
        <source>Related</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="440"/>
        <location filename="../VideoInfoView.qml" line="443"/>
        <source>By </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="511"/>
        <source>Views</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="525"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="541"/>
        <source>Tags</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="611"/>
        <source>No comments</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="611"/>
        <source> comments</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="704"/>
        <source>No related videos</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>VideoListDelegate</name>
    <message>
        <location filename="../VideoListDelegate.qml" line="52"/>
        <source>By </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="52"/>
        <source> on </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="102"/>
        <source>Views</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VideoListView</name>
    <message>
        <location filename="../VideoListView.qml" line="57"/>
        <source>Multi-select</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="59"/>
        <source>Download video</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="59"/>
        <source>Download audio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="60"/>
        <source>Add to favourites</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="60"/>
        <source>Add to playlist</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="60"/>
        <source>Copy to clipboard</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="114"/>
        <source>No videos found</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>VideoPlaybackView</name>
    <message>
        <location filename="../VideoPlaybackView.qml" line="60"/>
        <source>Error: Unable to retrieve video</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTube</name>
    <message>
        <location filename="../../../youtube.cpp" line="39"/>
        <source>Error obtaining access token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="49"/>
        <source>Authentication failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="52"/>
        <source>You are signed in to YouTube as &apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="114"/>
        <location filename="../../../youtube.cpp" line="220"/>
        <source>Error - Server repsonse is: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="164"/>
        <location filename="../../../youtube.cpp" line="172"/>
        <source>Upload aborted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="179"/>
        <source>Upload interrupted. Attempting to resume...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="183"/>
        <source>Upload failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="189"/>
        <source>Upload is completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="379"/>
        <source>Error: Unable to retrieve video</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="12"/>
        <location filename="../main.qml" line="15"/>
        <location filename="../main.qml" line="16"/>
        <location filename="../main.qml" line="17"/>
        <location filename="../main.qml" line="18"/>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="103"/>
        <source>Video(s) added to download queue</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="114"/>
        <source>Audio track(s) added to download queue</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="145"/>
        <source>Video added to favourites</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="146"/>
        <source>Video added to playlist</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="153"/>
        <source>New playlist created</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="193"/>
        <source>Converting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="202"/>
        <source>Conversion of &apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="202"/>
        <source>&apos; failed</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="216"/>
        <location filename="../main.qml" line="223"/>
        <location filename="../main.qml" line="263"/>
        <source>Queued</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="231"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="411"/>
        <source>Most Recent</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="412"/>
        <source>Most Viewed</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>mainscripts</name>
    <message>
        <location filename="../scripts/mainscripts.js" line="19"/>
        <source>Media Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="119"/>
        <source>My Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="133"/>
        <source>Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="172"/>
        <source>My Playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="182"/>
        <source>My Subscriptions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="195"/>
        <source>Video Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="204"/>
        <source>Video Playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="214"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="222"/>
        <source>date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="225"/>
        <source>views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="228"/>
        <source>relevance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="231"/>
        <source>rating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="237"/>
        <source>Search </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>settings</name>
    <message>
        <location filename="../scripts/settings.js" line="126"/>
        <location filename="../scripts/settings.js" line="127"/>
        <source>High Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/settings.js" line="128"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/settings.js" line="130"/>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/settings.js" line="131"/>
        <source>Media Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/settings.js" line="132"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/settings.js" line="133"/>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../scripts/settings.js" line="134"/>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
